@@ -1,12 +1,12 @@
 import pymysql
-import html
+from pymoran.strtool import StrClass
 
 
 class MySQLClient:
     def __init__(self, dbdata: dict) -> None:
         '''
         初始化数据库连接
-        :param dbdata host 主机地址,user 用户名,password 密码,database 数据库,port 端口，默认3306
+        :param dbdata(host 主机地址,user 用户名,password 密码,database 数据库,port 端口，默认3306)
         :return {bool} True/False
         '''
         # 打开数据库连接
@@ -19,28 +19,11 @@ class MySQLClient:
         )
         # 使用cursor()方法获取操作游标
         self.cursor = self.db.cursor()
+        self.strclass=StrClass()
 
     def close(self):
         self.db.close()
 
-    def html_escape(self, value: str):
-        '''
-        对传输的值进行html编码
-        :param value 需要转换的字符串
-        :return 编码后的字符串
-        '''
-        if type(value) == int:
-            return str(value)
-        return html.escape(value)
-
-    def html_unescape(self, value: str):
-        '''
-        对传输的值进行html解码
-        :param value 需要转换的字符串
-        :return 解码后的字符串
-        '''
-        return html.unescape(value)
-
     def insert(self, table: str, data: dict, close: bool = True):
         '''
         插入数据，插入的数据内容无需做特殊安全处理，方法内均进行了html转码保存数据
@@ -56,7 +39,7 @@ class MySQLClient:
         row = []
         for d in data.keys():
             col.append(d)
-            row.append('"'+self.html_escape(data[d])+'"')
+            row.append('"'+self.strclass.html_escape(data[d])+'"')
         sql = 'INSERT INTO %s (%s) VALUES (%s)' % (
             table,
             ','.join(col),
@@ -76,22 +59,30 @@ class MySQLClient:
             self.close()
         return result
 
-    def fetch(self, fields: list, table: str, query: str = '', close: bool = True):
+    def fetch(self, fields: list, table: str, query: str = '', orderby: dict = None, close: bool = True):
         '''
         查询数据，查询条件数据建议使用html_escape转码保证数据查询安全
         :param fields 要查询的字段名
         :param table 表名
         :param query 查询条件，默认为空
+        :param orderby 排序，默认为空，例：{'sort':'desc'}
         :param close 是否自动关闭数据库连接，默认True
         :return {list} 如没有查询结果则返回None
         '''
         where_str = ''
         if query != '':
             where_str = 'WHERE %s' % query
-        sql = 'SELECT %s FROM %s %s' % (
+        orderby_str = ''
+        if orderby != None:
+            orderby_arr = []
+            for key in orderby.keys():
+                orderby_arr.append('%s %s' % (key, orderby[key]))
+            orderby_str = 'ORDER BY ' + ','.join(orderby_arr)
+        sql = 'SELECT %s FROM %s %s %s' % (
             ','.join(fields),
             table,
-            where_str
+            where_str,
+            orderby_str
         )
         try:
             # 执行SQL语句
@@ -120,7 +111,7 @@ class MySQLClient:
         '''
         查询数据结果条数，查询条件数据建议使用html_escape转码保证数据查询安全
         :param table 表名
-        :param query 查询条件
+        :param query where后的查询条件，例：id=1 and name='张三'
         :param close 是否自动关闭数据库连接，默认True
         :return {list} 如没有查询结果则返回None
         '''
@@ -160,7 +151,7 @@ class MySQLClient:
         set_list = []
         for key in set.keys():
             set_list.append(
-                '%s="%s"' % (key, self.html_escape(set[key]))
+                '%s="%s"' % (key, self.strclass.html_escape(set[key]))
             )
         sql = 'UPDATE %s SET %s %s' % (
             table,
